@@ -22,12 +22,26 @@ typedef enum InterpolateKernelType {
 	KERNEL_GAUSSIAN,
 	KERNEL_INVNTH,
 	KERNEL_BRUSH,
+	KERNEL_BRUSH_FLIPPED,
+	KERNEL_BILINEAR,
+	KERNEL_BINTH,
+	KERNEL_SINC,
+	KERNEL_SINC_LANCZOS,
+	KERNEL_SINC_R,
 } InterpolateKernelType;
 
+typedef enum InterpolateMethod {
+	METHOD_OLD_CENTER,
+	METHOD_LEASTSQ_CENTER,
+	METHOD_FLAT_AVERAGES,
+	METHOD_LEASTSQ,
+	METHOD_QUADRATIC,
+} InterpolateMethod;
+
 typedef struct {
 	gint chanid;
 	gboolean usesel;
-	gboolean halfsel;
+	gint halfsel;
 
 	gint window;
 	gfloat sigma;
@@ -35,7 +49,7 @@ typedef struct {
 	gboolean newlayer;
 
 	gboolean slopes;
-	gboolean leastsq;
+	InterpolateMethod method;
 	gint linwindow;
 	gfloat linsigma;
 	InterpolateKernelType linkernel;
@@ -48,10 +62,36 @@ typedef struct {
 	gboolean multmask;
 
 	gboolean all_white_input;
+
+	gboolean gamma_compensation;
+	gfloat gamma;
+	gint grid, grid_y;
+	gint offs, offs_y;
+
+	gfloat norm;
+	gfloat linnorm;
+
+	gfloat slopesmult;
+
+	gint window_y;
+	gint linwindow_y;
+
+	gfloat kernel_cap;
+	gfloat kernel_base;
+	gfloat linkernel_cap;
+	gfloat linkernel_base;
+
+	gboolean slopesmask;
+	gint slopeschanid;
+	gboolean slopesmaskwhite;
+	gboolean slopessubsel;
+	gint linhalfsel;
+	gboolean slopesweights;
 } PlugInVals;
 
 typedef struct {
 	gboolean preview;
+	gboolean sepaxes;
 } PlugInUIVals;
 
 /*  Default values  */
