@@ -9,6 +9,17 @@
 #ifndef __RENDER_H__
 #define __RENDER_H__
 
-void render(gint32 image_ID, GimpDrawable *drawable, PlugInVals *vals);
+#include "main.h"
+
+#include <libgimp/gimpui.h>
+
+
+typedef struct InterpolateInvocation {
+	GimpDrawable *drawable;
+	PlugInVals *vals;
+} InterpolateInvocation;
+
+void invoke_render(InterpolateInvocation *inv, GimpPreview *preview);
+void render(GimpDrawable *drawable, PlugInVals *vals, GimpPreview *preview);
 
 #endif /* __RENDER_H__ */
